@@ -276,7 +276,7 @@ namespace PythonDCOP {
   {
 
     m_type = 0;
-    m_params.setAutoDelete( TRUE );
+    m_params.setAutoDelete( true );
 
     // Find the space that separates the type from the name
     int k  = signature.find( ' ' );
