@@ -163,7 +163,7 @@ TQCanvasItem *TQCanvasItemImp::toTQCanvasItem( KJS::Object &self )
     if ( !op )
         return 0;
 /*
-    if ( !op->inherits(TQCANVASITEM_OBJECT_NAME_STRING) ) {
+    if ( !op->inherits("TQCanvasItem") ) {
 	kdDebug() << "Typename of opaque canvas item is " << op->typeName() << endl;
 	// Check superclasses
         return 0;
@@ -782,9 +782,3 @@ KJS::Value TQCanvasItemImp::canvas_40( KJS::ExecState *exec, KJS::Object &obj, c
 
 
 } // namespace KJSEmbed
-
-// Local Variables:
-// c-basic-offset: 4
-// End:
-
-
