@@ -5,7 +5,7 @@ require 'Qt'
     hello = TQt::PushButton.new( "Hello world!", nil )
     hello.resize( 100, 30 )
  
-    TQt::Object::connect( hello, SIGNAL('clicked()'), a, SLOT('quit()') )
+    TQt::Object::connect( hello, TQ_SIGNAL('clicked()'), a, TQ_SLOT('quit()') )
  
     a.setMainWidget( hello )
     hello.show()
