@@ -29,7 +29,7 @@ public static void main( String[] args )
 	s = "Hello, World";
     Hello h = new Hello( s );
     h.setCaption( "Qt says hello" );
-    TQObject.connect( h, Qt.SIGNAL("clicked()"), a, Qt.SLOT("quit()") );
+    TQObject.connect( h, Qt.TQ_SIGNAL("clicked()"), a, Qt.TQ_SLOT("quit()") );
     h.setFont( new TQFont("times",32,TQFont.Bold) );		// default font
     h.setBackgroundColor( Qt.white() );			// default bg color
     a.setMainWidget( h );
