@@ -17,7 +17,7 @@ public static void main(String[] args) {
     ApplicationWindow  mw = new ApplicationWindow();
     mw.setCaption( "Qt Example - Multiple Documents Interface (MDI)" );
     mw.show();
-    a.connect( a, Qt.SIGNAL("lastWindowClosed()"), a, Qt.SLOT("quit()") );
+    a.connect( a, Qt.TQ_SIGNAL("lastWindowClosed()"), a, Qt.TQ_SLOT("quit()") );
     int res = a.exec();
     return;
 }
