@@ -334,7 +334,7 @@ namespace QtSharp {
                                         tmp=tmp.NextSibling as XmlElement;
                                         String slot=tmp.InnerText;
 
-                                        writer.WriteLine("\t\tTQObject.Connect({0},TQT_SIGNAL(\"{1}\"),{2},TQT_SLOT(\"{3}\"));",
+                                        writer.WriteLine("\t\tTQObject.Connect({0},TQ_SIGNAL(\"{1}\"),{2},TQ_SLOT(\"{3}\"));",
 						sender,signal,receiver,slot);
                                 }
                                 break;
